<?php

namespace DsbNext\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util;
use Teknisa\Libs\Util\NewCode;

class ParametersDashboardController {
    protected $crudService;
    protected $newCode;
    protected $service;
  
    public function __construct($connection, $environment, $util, $crudService, $newCode, $service) {
        $this->connection   = $connection;
        $this->environment  = $environment;
        $this->util         = $util;
        $this->crudService	= $crudService;
        $this->newCode	    = $newCode;
        $this->service      = $service;
    }
  
    public function addProfileAccess(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try {
            $this->service->beginTransaction();
          
            $nrperfaclpainel = intval($this->newCode->getCodeByTableName("PERFACLPAINEL", $this->environment->getNrOrgTrab()));
            $params = [
                "NRPERFACLPAINEL" => $nrperfaclpainel,
                "NRPAINEL" => $row["NRPAINEL"],
                "NRPERFILACESSO" => $row["NRPERFILACESSO"],
                "CDFILIAL" => $row["CDFILIAL"],
                "IDPADRAODASH" => $row["IDPADRAODASH"],
                "NRORG" => $this->environment->getNrorg()
            ];
           $this->service->insertProfile($params);
          
           $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function dellProfileAccess(Request\DataSet $request, Response $response) {
        $data = $request->getParameters();
        try {
            $this->service->beginTransaction();
            foreach ($data["dataset"] as $row) {
                $params = [
                    "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"]
                ];
                $this->service->deleteProfileAccess($params);
            }
          $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function rowsProfileUpdate(Request\DataSet $request, Response $response) {
        $data = $request->getParameters();
        try {
            $this->service->beginTransaction();
            foreach ($data["dataset"] as $row) {
                $params = [
                    "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"],
                    "IDPADRAODASH" => $row["IDPADRAODASH"],
                    "CDFILIAL" => $row["CDFILIAL"]
                ];
                $this->service->rowsProfileUpdate($params);
            }
          $this->service->commit();  
        }catch(\Exception $ex) {
          $this->service->rollback();
          $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function rowsUpdateIndicator(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try{
            $this->service->beginTransaction();
            foreach($row['INDICATOR'] as $indicator){
                if(!isset($indicator['NRINDICPAINEL'])){
                    $nrindicpainel = intval($this->newCode->getCodeByTableName("INDICPAINEL", $this->environment->getNrOrgTrab()));
                    $params = [
                        "NRINDICPAINEL" => $nrindicpainel,
                        "NRPERFACLPAINEL" => intval($indicator['NRPERFACLPAINEL']),
                        "NRINDICADORTF" => $indicator["NRINDICADORTF"],
                        "IDVISUINDIC" => $indicator["IDVISUINDIC"],
                        "NRORG" => $this->environment->getNrorg()
                    ];
                    $this->service->insertIndicpanel($params);
                }else{
                    $params = [
                        "NRINDICPAINEL" => $indicator["NRINDICPAINEL"],
                        "IDVISUINDIC" => $indicator["IDVISUINDIC"],
                        "NRORG" => $this->environment->getNrorg()
                    ];
                    $this->service->updateIndicpanel($params);
                }
            }
                $this->service->commit();
        }catch(\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function deleteOperatorEx(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try{
            $this->service->beginTransaction();
            $cdoperador = [];
            foreach ($row['OPERADOR'] as $operator){
                if(preg_match('/^([a-z0-9A-Z]){12}$/', $operator['CDOPERADOR'])){
                    array_push($cdoperador, "'".$operator['CDOPERADOR']."'");
                }
            }
            $params = [
                "NRPERFILACESSO" => $row["NRPERFILACESSO"],
                "NRPAINEL" => $row["NRPAINEL"],
                "CDFILIAL" => $row["CDFILIAL"]
            ];
            $this->service->deleteOperatorEx($params, $cdoperador);
            $this->service->commit();
        }catch(\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function deleteOperatorExInd(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try{
            $this->service->beginTransaction();
            $nrindicpainexoper = [];
            foreach ($row['NRINDICPAINEXCOPER'] as $nrIndic){
                array_push($nrindicpainexoper, $nrIndic['NRINDICPAINEXCOPER']);
            }
            $this->service->deleteOperatorExInd($nrindicpainexoper);
            $this->service->commit();
        }catch(\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function saveExOperadorPainel(Request\DataSet $request, Response $response) {
        $currentRow = $request->getRows()[0];
        $nrorg = $this->environment->getNrorg();
        $filterCountIndicadortf = [
            "NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"]
        ];
        $countIndicadortf = $this->service->countIndicadortf($filterCountIndicadortf);
        
        if(!empty($countIndicadortf)){
            $nrindicpainel = intval($this->newCode->getCodeByTableName('INDICPAINEL', $this->environment->getNrOrgTrab(), $countIndicadortf));
            if($nrindicpainel != 1){
                $nrindicpainel = $nrindicpainel - 1;    
            }
            $filterInsertAllIndicador = array(
                "NRINDICPAINEL" => $nrindicpainel,
                "NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"],
                "NRORG" => $nrorg,
                "NRPAINEL" => $currentRow["NRPAINEL"]
            );
            $this->service->insertAllIndicpainel($filterInsertAllIndicador);
        }
        $filterCountIndicpainel = array(
            "NRPAINEL" => $currentRow["NRPAINEL"]
        );
        $countIndicador = $this->service->countIndicador($filterCountIndicpainel);
        
        foreach($currentRow["OPERADOR"] as $cdoperador){
            $nrindicpainexoper = intval($this->newCode->getCodeByTableName('INDICPAINEXCOPER', $nrorg, $countIndicador));
            if($nrindicpainexoper != 1){
                $nrindicpainexoper = $nrindicpainexoper - 1;
            }
            $filterInsertOperador = array(
                "NRINDICPAINEXOPER" => $nrindicpainexoper,
                "NRPERFACLPAINEL" => $currentRow["NRPERFACLPAINEL"],
                "CDFILIAL" => $currentRow["CDFILIAL"],
                "CDOPERADOR" => $cdoperador,
                "NRORG" => $nrorg
            );
    		$this->service->insertExOperadorPainel($filterInsertOperador);
        }
    }
    
    public function insertExOperator(Request\Row $request, Response $response) {
        $row = $request->getRow();
        $filterCountIndicatortf = [
            "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"]
        ];
        $nrorg = $this->environment->getNrorg();
        $countIndicatortf = $this->service->countIndicatortf($filterCountIndicatortf);
        if(!empty($countIndicatortf)){
            $nrindicpanel = intval($this->newCode->getCodeByTableName('INDICPAINEL', $this->environment->getNrOrgTrab(), $countIndicatortf));
            if($nrindicpanel != 1){
                $nrindicpanel = $nrindicpanel - 1;    
            }
            $filterInsertAllIndicator = [
                "NRINDICPAINEL" => $nrindicpanel,
                "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"],
                "NRORG" => $nrorg,
                "NRPAINEL" => $row["NRPAINEL"]
            ];
            
            $this->service->insertAllIndicpanel($filterInsertAllIndicator);
        }
         $filterCountIndicpanel = [
            "NRPAINEL" => $row["NRPAINEL"]
        ];
        $countIndicator = $this->service->countIndicator($filterCountIndicpanel);
        
        foreach($row["OPERATOR"] as $cdoperador){
            $nrindicpanelxoper = intval($this->newCode->getCodeByTableName('INDICPAINEXCOPER', $nrorg, $countIndicator));
            if($nrindicpanelxoper != 1){
                $nrindicpanelxoper = $nrindicpanelxoper - 1;
            }
            $filterInsertOperator = [
                "NRINDICPAINEXOPER" => $nrindicpanelxoper,
                "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"],
                "CDFILIAL" => $row["CDFILIAL"],
                "CDOPERADOR" => $cdoperador,
                "NRORG" => $nrorg
            ];
    		$this->service->insertExOperatorPanel($filterInsertOperator);
        }
    }
    
    public function saveExOperatorIndicator(Request\Row $request, Response $response) {
        $row = $request->getRow();
        $nrorg = $this->environment->getNrOrgTrab();
        try{
            $this->service->beginTransaction();
            foreach($row['OPERATOR'] as $cdoperador){   
                $nrindicpainexcoper = intval($this->newCode->getCodeByTableName('INDICPAINEXCOPER', $this->environment->getNrOrgTrab()));
                $params = [
                    "NRINDICPAINEXCOPER" => $nrindicpainexcoper,
                    "NRINDICPAINEL" => $row["NRINDICPAINEL"],
                    "CDOPERADOR" => $cdoperador,
                    "NRORG" => $nrorg
                ];
                $this->service->insertExOperatorIndicator($params);
            }
            $this->service->commit();
		}catch(\Exception $ex) {
		    $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function reviewFiltePanel (Request\Filter $request, Response $response){
        $this->service->beginTransaction();
        $params = ["NRORG" => $this->environment->getNrorg()];
        try {
            $nrpainel = $this->service->checkedPanel();
            if(!empty($nrpainel)){
                $this->service->insertPanel($nrpainel, $params); 
            }
            $this->service->checkIndicator();
            $this->service->commit();
        } catch (Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        } 
    }
    
    public function checkLabelName(Request\Row $request, Response $response) {
        $row = $request->getRow();
        $params = [ 
            "NRPERFACLPAINEL" => $row["NRPERFACLPAINEL"],
            "NRPAINEL" => $row["NRPAINEL"]
        ];
        try {
            $dataIndicator = $this->service->checkLabelName($params);
            $response->addDataSet(new DataSet("checkLabelName", $dataIndicator));
        } catch (Exception $ex) {
            $response->setError(new Error($ex->getMessage(), 500));
        } 
    }
    
    public function validateDisabledInput(Request\Row $request, Response $response) {
        $row = $request->getRow();
        $params = [ 
            "CDFILIAL"   => $row["CDFILIAL"],
            "CDOPERADOR" => $this->environment->getCdOperador()
        ];
        try {
            $data = $this->service->validateDisabledInput($params);
            $response->addDataSet(new DataSet("validateDisabledInput", $data));
        } catch (Exception $ex) {
            $response->setError(new Error($ex->getMessage(), 500));
        } 
    }
    
    public function saveExceptionReplicate(Request\Row $request, Response $response) {
        $row = $request->getRow();
        $nrorg = $this->environment->getNrorg();
        try{
            if($row['ALLUNITS'] == 'T'){
                $nrlista = 'T';
                $paramsDelete = [
                    "CDFILIAL" => $row['CDFILIALORIGIN'],
                    "NRPAINEL" => null,
                    "NRORG" => $nrorg
                ];
                $this->service->deleteAllUnit($paramsDelete);
            }else{
                $nrlista = $this->util->insertLista($row['CDFILIALDESTINY']);
                $paramsDelete = [
                    "NRLISTA" => $nrlista,
                    "NRPAINEL" => null,
                    "NRORG" => $nrorg
                ];
                $this->service->deleteParameterUnit($paramsDelete);
            }
            if($nrlista) {
                $paramsReplicate = [
                    "NRLISTA" => $nrlista,
                    "CDFILIAL" => $row['CDFILIALORIGIN'],
                    "NRORG" => $nrorg
                ];
                $this->service->insertReplicate($paramsReplicate);
                
                if ($nrlista != 'T') {
                    $this->util->deleteLista($nrlista);
                }
            }
        }catch(Exception $ex) {
            if($nrlista) { 
                $this->util->deleteLista($nrlista);
            }
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
}