import {
  Metadata,
  Http,
} from '@zeedhi/core';
import {
  Modal,
  ModalService,
  Select,
  SelectMultiple,
  GridEditable,
  Form,
  Checkbox,
} from '@zeedhi/common';

export class ExceptionReplicateModalController {
  private exceptionReplicate!: Modal;

  public async createExceptionReplicate() {
    this.exceptionReplicate = await ModalService.createFromJson('/modals/exceptionReplicateModal', true);
  }

  public openExceptionReplicate() {
    this.exceptionReplicate.show();
  }

  public closeExceptionReplicate() {
    const selectMultiple = Metadata.getInstance<SelectMultiple>('cdfilialDestiny');
    const form = Metadata.getInstance<Form>('formExceptionReplication');
    selectMultiple.disabled = true;
    form.clearForm();
    this.exceptionReplicate.hide();
  }
  
  public validateDisabledInput() {
    const select = Metadata.getInstance<Select>('cdfilialOrigin');
    const selectMultiple = Metadata.getInstance<SelectMultiple>('cdfilialDestiny');
    const checkbox = Metadata.getInstance<Checkbox>('allUnits');
    const sendObject = {
      CDFILIAL: select.value,
    };
    Http.post('/validateDisabledInput', {
      requestType: 'Row',
      row: sendObject,
    }).then((response) => {
      const data = response.data.dataset.validateDisabledInput;
      selectMultiple.updateData(data);
      selectMultiple.disabled = false;
      checkbox.disabled = false;
    });
  }
  
  public saveExceptionReplicate() {
    const form = Metadata.getInstance<Form>('formExceptionReplication');
    const grid = Metadata.getInstance<GridEditable>('parametersEditGrid');
    const selectMultiple = Metadata.getInstance<SelectMultiple>('cdfilialDestiny');
    const checkbox = Metadata.getInstance<Checkbox>('allUnits');
    const sendObject = {
      CDFILIALORIGIN: form.value.cdfilialOrigin,
      CDFILIALDESTINY: form.value.cdfilialDestiny,
      ALLUNITS: form.value.allUnits,
    };
    Http.post('/saveExceptionReplicate', {
      requestType: 'Row',
      row: sendObject,
    }).then(() => {
      grid.datasource.get();
      form.clearForm();
      this.exceptionReplicate.hide();
      selectMultiple.disabled = false;
      checkbox.disabled = false;
    });
  }
  
  public changeDisableInput() {
    const selectMultiple = Metadata.getInstance<SelectMultiple>('cdfilialDestiny');
    const checkbox = Metadata.getInstance<Checkbox>('allUnits');
    if (checkbox.value === 'T') {
      selectMultiple.disabled = true;
      selectMultiple.value = '';
    } else {
      selectMultiple.disabled = false;
    }
  }
}
